Skip site navigation (1)Skip section navigation (2)
Date:      Thu, 21 Mar 2019 00:11:44 +0000 (UTC)
From:      Alan Somers <asomers@FreeBSD.org>
To:        src-committers@freebsd.org, svn-src-projects@freebsd.org
Subject:   svn commit: r345356 - in projects/fuse2: etc/mtree tests/sys/fs tests/sys/fs/fuse tests/sys/fs/fusefs
Message-ID:  <201903210011.x2L0BiHx035578@repo.freebsd.org>

next in thread | raw e-mail | index | archive | help
Author: asomers
Date: Thu Mar 21 00:11:43 2019
New Revision: 345356
URL: https://svnweb.freebsd.org/changeset/base/345356

Log:
  fusefs: adapt the tests to the fuse => fusefs rename
  
  Sponsored by:	The FreeBSD Foundation

Added:
  projects/fuse2/tests/sys/fs/fusefs/
     - copied from r345355, projects/fuse2/tests/sys/fs/fuse/
Deleted:
  projects/fuse2/tests/sys/fs/fuse/
Modified:
  projects/fuse2/etc/mtree/BSD.tests.dist
  projects/fuse2/tests/sys/fs/Makefile
  projects/fuse2/tests/sys/fs/fusefs/Makefile
  projects/fuse2/tests/sys/fs/fusefs/mockfs.hh
  projects/fuse2/tests/sys/fs/fusefs/utils.cc
  projects/fuse2/tests/sys/fs/fusefs/write.cc

Modified: projects/fuse2/etc/mtree/BSD.tests.dist
==============================================================================
--- projects/fuse2/etc/mtree/BSD.tests.dist	Wed Mar 20 23:35:15 2019	(r345355)
+++ projects/fuse2/etc/mtree/BSD.tests.dist	Thu Mar 21 00:11:43 2019	(r345356)
@@ -713,7 +713,7 @@
         file
         ..
         fs
-            fuse
+            fusefs
             ..
             tmpfs
             ..

Modified: projects/fuse2/tests/sys/fs/Makefile
==============================================================================
--- projects/fuse2/tests/sys/fs/Makefile	Wed Mar 20 23:35:15 2019	(r345355)
+++ projects/fuse2/tests/sys/fs/Makefile	Thu Mar 21 00:11:43 2019	(r345356)
@@ -7,7 +7,7 @@ TESTSDIR=		${TESTSBASE}/sys/fs
 TESTSRC=		${SRCTOP}/contrib/netbsd-tests/fs
 
 #TESTS_SUBDIRS+=	nullfs	# XXX: needs rump
-TESTS_SUBDIRS+=		fuse
+TESTS_SUBDIRS+=		fusefs
 TESTS_SUBDIRS+=		tmpfs
 
 ${PACKAGE}FILES+=	h_funcs.subr

Modified: projects/fuse2/tests/sys/fs/fusefs/Makefile
==============================================================================
--- projects/fuse2/tests/sys/fs/fuse/Makefile	Wed Mar 20 23:35:15 2019	(r345355)
+++ projects/fuse2/tests/sys/fs/fusefs/Makefile	Thu Mar 21 00:11:43 2019	(r345356)
@@ -2,7 +2,7 @@
 
 PACKAGE=	tests
 
-TESTSDIR=	${TESTSBASE}/sys/fs/fuse
+TESTSDIR=	${TESTSBASE}/sys/fs/fusefs
 
 # We could simply link all of these files into a single executable.  But since
 # Kyua treats googletest programs as plain tests, it's better to separate them

Modified: projects/fuse2/tests/sys/fs/fusefs/mockfs.hh
==============================================================================
--- projects/fuse2/tests/sys/fs/fuse/mockfs.hh	Wed Mar 20 23:35:15 2019	(r345355)
+++ projects/fuse2/tests/sys/fs/fusefs/mockfs.hh	Thu Mar 21 00:11:43 2019	(r345356)
@@ -171,7 +171,7 @@ ProcessMockerT ReturnImmediate(
  * "Mounts" a filesystem to a temporary directory and services requests
  * according to the programmed expectations.
  *
- * Operates directly on the fuse(4) kernel API, not the libfuse(3) user api.
+ * Operates directly on the fusefs(4) kernel API, not the libfuse(3) user api.
  */
 class MockFS {
 	/*

Modified: projects/fuse2/tests/sys/fs/fusefs/utils.cc
==============================================================================
--- projects/fuse2/tests/sys/fs/fuse/utils.cc	Wed Mar 20 23:35:15 2019	(r345355)
+++ projects/fuse2/tests/sys/fs/fusefs/utils.cc	Thu Mar 21 00:11:43 2019	(r345356)
@@ -40,10 +40,10 @@
 
 using namespace testing;
 
 /* Check that fuse(4) is accessible and the current user can mount(2) */
 void check_environment()
 {
-	const char *mod_name = "fuse";
+	const char *mod_name = "fusefs";
 	const char *devnode = "/dev/fuse";
 	const char *usermount_node = "vfs.usermount";
 	int usermount_val = 0;
@@ -40,10 +40,10 @@
 using namespace testing;
 
-/* Check that fuse(4) is accessible and the current user can mount(2) */
+/* Check that fusefs(4) is accessible and the current user can mount(2) */
 void check_environment()
 {

Modified: projects/fuse2/tests/sys/fs/fusefs/write.cc
==============================================================================
--- projects/fuse2/tests/sys/fs/fuse/write.cc	Wed Mar 20 23:35:15 2019	(r345355)
+++ projects/fuse2/tests/sys/fs/fusefs/write.cc	Thu Mar 21 00:11:43 2019	(r345356)
@@ -66,7 +66,7 @@ void expect_release(uint64_t ino, ProcessMockerT r)
 }
 
 void require_sync_resize_0() {
-	const char *sync_resize_node = "vfs.fuse.sync_resize";
+	const char *sync_resize_node = "vfs.fusefs.sync_resize";
 	int val = 0;
 	size_t size = sizeof(val);
 
@@ -74,7 +74,7 @@ void require_sync_resize_0() {
 		<< strerror(errno);
 	if (val != 0)
 		GTEST_SKIP() <<
-			"vfs.fuse.sync_resize must be set to 0 for this test."
+			"vfs.fusefs.sync_resize must be set to 0 for this test."
 			"  That sysctl will probably be removed soon.";
 }
 
@@ -100,7 +100,7 @@ virtual void SetUp() {
 class WriteThrough: public Write {
 
 virtual void SetUp() {
-	const char *cache_mode_node = "vfs.fuse.data_cache_mode";
+	const char *cache_mode_node = "vfs.fusefs.data_cache_mode";
 	int val = 0;
 	size_t size = sizeof(val);
 
@@ -111,7 +111,7 @@ virtual void SetUp() {
 	ASSERT_EQ(0, sysctlbyname(cache_mode_node, &val, &size, NULL, 0))
 		<< strerror(errno);
 	if (val != 1)
-		GTEST_SKIP() << "vfs.fuse.data_cache_mode must be set to 1 "
+		GTEST_SKIP() << "vfs.fusefs.data_cache_mode must be set to 1 "
 			"(writethrough) for this test";
 }
 
@@ -121,7 +121,7 @@ virtual void SetUp() {
 class WriteBack: public Write {
 
 virtual void SetUp() {
-	const char *node = "vfs.fuse.data_cache_mode";
+	const char *node = "vfs.fusefs.data_cache_mode";
 	int val = 0;
 	size_t size = sizeof(val);
 
@@ -132,7 +132,7 @@ virtual void SetUp() {
 	ASSERT_EQ(0, sysctlbyname(node, &val, &size, NULL, 0))
 		<< strerror(errno);
 	if (val != 2)
-		GTEST_SKIP() << "vfs.fuse.data_cache_mode must be set to 2 "
+		GTEST_SKIP() << "vfs.fusefs.data_cache_mode must be set to 2 "
 			"(writeback) for this test";
 }
 
@@ -343,7 +343,7 @@ TEST_F(Write, DISABLED_direct_io_short_write_iov)
  * write, then it must set the FUSE_WRITE_CACHE bit
  */
 /* https://bugs.freebsd.org/bugzilla/show_bug.cgi?id=236378 */
 // TODO: check vfs.fuse.mmap_enable
 TEST_F(Write, DISABLED_mmap)
 {
 	const char FULLPATH[] = "mountpoint/some_file.txt";
@@ -343,7 +343,7 @@ TEST_F(Write, DISABLED_direct_io_short_write_iov)
  */
 /* https://bugs.freebsd.org/bugzilla/show_bug.cgi?id=236378 */
-// TODO: check vfs.fuse.mmap_enable
+// TODO: check vfs.fusefs.mmap_enable
 TEST_F(Write, DISABLED_mmap)
 {



Want to link to this message? Use this URL: <https://mail-archive.FreeBSD.org/cgi/mid.cgi?201903210011.x2L0BiHx035578>